@@ -33,8 +33,8 @@ def pull_files_s3(prefix: str, file_type: str, s3_bucket, delimiter='/') -> str:
 
 def create_labeling_project(labelbox_api_key: str,
                             data: Union[str, Path, pd.DataFrame], annotation_col: str, id_col: str,
-                            dataset_name: str, project_name: str, project_desc: Optional[str] = '',
-                            s3_bucket_name: str = 'test-labelbox-edelman', prefix: Optional[str] = None,
+                            s3_bucket_name: str, dataset_name: str, project_name: str, project_desc: Optional[str] = '',
+                            prefix: Optional[str] = None,
                             temp_data_path: Optional[Union[str, Path]] = None) -> dict:
     """create_labeling_project creates labelling project. dataset and attaches data to project from dxi S3 bucket.
 
